# hb-mep

## Setup Instructions

Requires Python >=3.11

### Create environment
```
python3 -m venv .venv

```

### Activate environment
```
source .venv/bin/activate

```

### Install hbmep
```
pip install hbmep

```

Tutorial: https://github.com/hbmep/hbmep/blob/dev/notebooks/tutorial.ipynb

## To do

- Add About section
- Create tutorial docs
- Add tests